==> AgeOn1.8.1_source.zip: AgeOn1.8.1_source/nispi/Controls/Menu/MainMenu/TabMenu/BoardListTabMainMenu.cs <==
//CZXAgeOntH_LISENCEtH_QƂĂ
using System;
using System.Collections.Generic;
using System.Text;
using System.Windows.Forms;
using System.Diagnostics;
using System.Drawing;

using nispi.controlclass;

namespace nispi
{
    class BoardListTabMainMenu
    {
        public ToolStripMenuItemParts menuItemCloseTabParts;
        public ToolStripMenuItemParts menuItemCloseAllTabParts;
        public ToolStripMenuItemParts menuItemAddFavoriteParts;
        public ToolStripMenuItemParts menuItemCreateNewThreadParts;
        public ToolStripMenuItemParts menuItemOpenBrowserParts;
        public ToolStripMenuItemParts menuItemCopyURLParts;
        public ToolStripMenuItemParts menuItemCopyTitleParts;
        public ToolStripMenuItemParts menuItemReloadParts;

        public BoardListTabEvent boardListTabEvent;

        public BoardListTabMainMenu(ToolStripMenuItemParts menuItem)
        {
            menuItemCloseTabParts = ToolStripMenuItemPartsManager.Pop();
            menuItemCloseAllTabParts = ToolStripMenuItemPartsManager.Pop();
            menuItemAddFavoriteParts = ToolStripMenuItemPartsManager.Pop();
            menuItemCreateNewThreadParts = ToolStripMenuItemPartsManager.Pop();
            menuItemOpenBrowserParts = ToolStripMenuItemPartsManager.Pop();
            menuItemCopyURLParts = ToolStripMenuItemPartsManager.Pop();
            menuItemCopyTitleParts = ToolStripMenuItemPartsManager.Pop();
            menuItemReloadParts = ToolStripMenuItemPartsManager.Pop();

            //Cj[ݒ
            menuItemCloseTabParts.Text = "^u";
            menuItemCloseAllTabParts.Text = "ׂẴ^u";
            menuItemAddFavoriteParts.Text = "Cɓɒǉ";

            menuItemCreateNewThreadParts.Text = "VKXbh쐬";
            menuItemOpenBrowserParts.Text = "uEU[ŊJ";

            menuItemCopyURLParts.Text = "URLRs[";
            menuItemCopyTitleParts.Text = "̖ORs[";
            menuItemReloadParts.Text = "ēǂݍ";

            menuItem.DropDownItemsAdd("-");
            menuItem.DropDownItemsAdd(menuItemCloseTabParts);
            menuItem.DropDownItemsAdd(menuItemCloseAllTabParts);
            menuItem.DropDownItemsAdd("-");
            //menuItem.DropDownItemsAdd(menuItemAddFavoriteParts);
            menuItem.DropDownItemsAdd(menuItemCreateNewThreadParts);

            //menuItem.DropDownItemsAdd(menuItemOpenBrowserParts);
            //menuItem.DropDownItemsAdd("-");
            //menuItem.DropDownItemsAdd(menuItemCopyURLParts);
            //menuItem.DropDownItemsAdd(menuItemCopyTitleParts);
            //menuItem.DropDownItemsAdd("-");
            menuItem.DropDownItemsAdd(menuItemReloadParts);

            boardListTabEvent = new BoardListTabEvent(this);
            menuItem.DropDownItemsAdd("-");
        }

        public void SetMenu()
        {
            int selectNum = Const.form.boardListTabControlParts.SelectedIndex;
            if (selectNum == 0)
            {
                //Cɓ̏ꍇ
                menuItemCloseTabParts.Enabled = false;
                menuItemCloseAllTabParts.Enabled = false;
                menuItemAddFavoriteParts.Enabled = false;
                menuItemCreateNewThreadParts.Enabled = false;
                menuItemOpenBrowserParts.Enabled = true;
                menuItemCopyURLParts.Enabled = true;
                menuItemCopyTitleParts.Enabled = true;
                menuItemReloadParts.Enabled = true;
            }
            else
            {
                if (Const.form.boardListTabControlParts.SelectedTabText.Length == 0)
                {
                    menuItemCloseTabParts.Enabled = false;
                    menuItemCloseAllTabParts.Enabled = false;
                    menuItemAddFavoriteParts.Enabled = false;
                    menuItemCreateNewThreadParts.Enabled = false;
                    menuItemOpenBrowserParts.Enabled = false;
                    menuItemCopyURLParts.Enabled = false;
                    menuItemCopyTitleParts.Enabled = false;
                    menuItemReloadParts.Enabled = false;
                }
                else
                {
                    menuItemCloseTabParts.Enabled = true;
                    menuItemCloseAllTabParts.Enabled = true;
                    menuItemAddFavoriteParts.Enabled = true;
                    menuItemCreateNewThreadParts.Enabled = true;
                    menuItemOpenBrowserParts.Enabled = true;
                    menuItemCopyURLParts.Enabled = true;
                    menuItemCopyTitleParts.Enabled = true;
                    menuItemReloadParts.Enabled = true;
                }
            }
        }
    }
}

==> AgeOn1.8.2_source.zip: AgeOn1.8.2_source/nispi/Controls/Menu/MainMenu/TabMenu/BoardListTabMainMenu.cs <==
//CZXAgeOntH_LISENCEtH_QƂĂ
using System;
using System.Collections.Generic;
using System.Text;
using System.Windows.Forms;
using System.Diagnostics;
using System.Drawing;

using nispi.controlclass;

namespace nispi
{
    class BoardListTabMainMenu
    {
        public ToolStripMenuItemParts menuItemCloseTabParts;
        public ToolStripMenuItemParts menuItemCloseAllTabParts;
        public ToolStripMenuItemParts menuItemAddFavoriteParts;
        public ToolStripMenuItemParts menuItemCreateNewThreadParts;
        public ToolStripMenuItemParts menuItemOpenBrowserParts;
        public ToolStripMenuItemParts menuItemCopyURLParts;
        public ToolStripMenuItemParts menuItemCopyTitleParts;
        public ToolStripMenuItemParts menuItemReloadParts;

        public BoardListTabEvent boardListTabEvent;

        public BoardListTabMainMenu(ToolStripMenuItemParts menuItem)
        {
            menuItemCloseTabParts = ToolStripMenuItemPartsManager.Pop();
            menuItemCloseAllTabParts = ToolStripMenuItemPartsManager.Pop();
            menuItemAddFavoriteParts = ToolStripMenuItemPartsManager.Pop();
            menuItemCreateNewThreadParts = ToolStripMenuItemPartsManager.Pop();
            menuItemOpenBrowserParts = ToolStripMenuItemPartsManager.Pop();
            menuItemCopyURLParts = ToolStripMenuItemPartsManager.Pop();
            menuItemCopyTitleParts = ToolStripMenuItemPartsManager.Pop();
            menuItemReloadParts = ToolStripMenuItemPartsManager.Pop();

            //Cj[ݒ
            menuItemCloseTabParts.Text = "^u(&W)(CTRL+W)";
            menuItemCloseAllTabParts.Text = "ׂẴ^u(&Q)(CTRL+Q)";
            menuItemAddFavoriteParts.Text = "Cɓɒǉ(&F)(CTRL+F)";

            menuItemCreateNewThreadParts.Text = "VKXbh쐬(&V)";
            menuItemOpenBrowserParts.Text = "uEU[ŊJ(&B)";

            menuItemCopyURLParts.Text = "URLRs[(&C)";
            menuItemCopyTitleParts.Text = "̖ORs[(&T)";
            menuItemReloadParts.Text = "ēǂݍ(&R)(CTRL+R)";

            menuItem.DropDownItemsAdd("-");
            menuItem.DropDownItemsAdd(menuItemCloseTabParts);
            menuItem.DropDownItemsAdd(menuItemCloseAllTabParts);
            menuItem.DropDownItemsAdd("-");
            //menuItem.DropDownItemsAdd(menuItemAddFavoriteParts);
            menuItem.DropDownItemsAdd(menuItemCreateNewThreadParts);

            //menuItem.DropDownItemsAdd(menuItemOpenBrowserParts);
            //menuItem.DropDownItemsAdd("-");
            //menuItem.DropDownItemsAdd(menuItemCopyURLParts);
            //menuItem.DropDownItemsAdd(menuItemCopyTitleParts);
            //menuItem.DropDownItemsAdd("-");
            menuItem.DropDownItemsAdd(menuItemReloadParts);

            boardListTabEvent = new BoardListTabEvent(this);
            menuItem.DropDownItemsAdd("-");
        }

        public void SetMenu()
        {
            int selectNum = Const.form.boardListTabControlParts.SelectedIndex;
            if (selectNum == 0)
            {
                //Cɓ̏ꍇ
                menuItemCloseTabParts.Enabled = false;
                menuItemCloseAllTabParts.Enabled = false;
                menuItemAddFavoriteParts.Enabled = false;
                menuItemCreateNewThreadParts.Enabled = false;
                menuItemOpenBrowserParts.Enabled = true;
                menuItemCopyURLParts.Enabled = true;
                menuItemCopyTitleParts.Enabled = true;
                menuItemReloadParts.Enabled = true;
            }
            else
            {
                if (Const.form.boardListTabControlParts.SelectedTabText.Length == 0)
                {
                    menuItemCloseTabParts.Enabled = false;
                    menuItemCloseAllTabParts.Enabled = false;
                    menuItemAddFavoriteParts.Enabled = false;
                    menuItemCreateNewThreadParts.Enabled = false;
                    menuItemOpenBrowserParts.Enabled = false;
                    menuItemCopyURLParts.Enabled = false;
                    menuItemCopyTitleParts.Enabled = false;
                    menuItemReloadParts.Enabled = false;
                }
                else
                {
                    menuItemCloseTabParts.Enabled = true;
                    menuItemCloseAllTabParts.Enabled = true;
                    menuItemAddFavoriteParts.Enabled = true;
                    menuItemCreateNewThreadParts.Enabled = true;
                    menuItemOpenBrowserParts.Enabled = true;
                    menuItemCopyURLParts.Enabled = true;
                    menuItemCopyTitleParts.Enabled = true;
                    menuItemReloadParts.Enabled = true;
                }
            }
        }
    }
}
